@@ -5,13 +5,13 @@
  *                                                                           *
  * This file is part of HDF.  The full HDF copyright notice, including       *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at      *
- * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: hdfi.h 6446 2016-06-15 16:54:36Z bmribler $ */
+/* $Id$ */
 
 #ifndef HDFI_H
 #define HDFI_H
@@ -48,7 +48,7 @@
 /*      8 - Cray IEEE                                                       */
 /*          (i.e. Big-Endian, all 64-bit architecture w/IEEE Floats)        */
 /*--------------------------------------------------------------------------*/
-#define     DFMT_SUN            0x1111 
+#define     DFMT_SUN            0x1111
 #define     DFMT_SUN_INTEL      0x4441
 #define     DFMT_ALLIANT        0x1111
 #define     DFMT_IRIX           0x1111
@@ -98,7 +98,7 @@
 /*
  * Meaning of each defined macros (not completed yet)
  *
- * BIG_LONGS--Define when long is not "equal" to int32.  True in cases
+ * H4_BIG_LONGS--Define when long is not "equal" to int32.  True in cases
  *      where (int32 *) is not compatible with (long *).  Should
  *      be renamed as LONGNEINT32.
  */
@@ -128,7 +128,7 @@ Please check your Makefile.
 #include <sys/file.h>               /* for unbuffered i/o stuff */
 #include <sys/stat.h>
 #if (defined __sun) && (defined __amd64 || defined __i386) /* SunOS on Intel; 32 and 64-bit modes */
-#define DF_MT   DFMT_SUN_INTEL 
+#define DF_MT   DFMT_SUN_INTEL
 #else
 #define DF_MT   DFMT_SUN
 #endif /* __sun */
@@ -186,7 +186,7 @@ Please check your Makefile.
 #define GOT_MACHINE
 
 #   define BSD
-#define DUMBCC 	/* because it is.  for later use in macros */
+#define DUMBCC     /* because it is.  for later use in macros */
 #ifndef __GNUC__
 #include <memory.h>
 #endif /* __GNUC__ */
@@ -253,11 +253,11 @@ Please check your Makefile.
 typedef void              VOID;
 typedef void              *VOIDP;
 typedef char              *_fcd;
-#ifndef _ALL_SOURCE       
+#ifndef _ALL_SOURCE
 typedef char              int8;
-typedef short int         int16; 
+typedef short int         int16;
 typedef int               int32;
-#endif  
+#endif
 typedef char              char8;
 typedef unsigned char     uchar8;
 typedef unsigned char     uint8;
@@ -406,7 +406,7 @@ typedef long               hdf_pint_t;   /* an integer the same size as a pointe
 #define FILELIB UNIXBUFIO
 /*
 #ifdef IRIX64
-#define BIG_LONGS
+#define H4_BIG_LONGS
 #endif
 */
 
@@ -488,7 +488,7 @@ typedef int               hdf_pint_t;   /* an integer the same size as a pointer
 
 #endif /* CONVEX */
 
- 
+
 #if defined (__APPLE__)
 
 #ifndef __APPLE__
@@ -506,7 +506,7 @@ Please check your Makefile.
 #define GOT_MACHINE 1
 
 #ifndef __GNUC__
-#define DUMBCC 	/* because it is.  for later use in macros */
+#define DUMBCC     /* because it is.  for later use in macros */
 #endif /* __GNUC__ */
 
 #include <sys/types.h>
@@ -567,7 +567,7 @@ typedef long            hdf_pint_t;   /* an integer the same size as a pointer *
 
 #if defined _WINDOWS || defined _WIN32
 #define WIN386
-#endif  /* _WINDOWS | _WIN32 */
+#endif  /* _WINDOWS | _WIN32_ */
 
 #if defined WIN386 || defined DOS386 || defined UNIX386
 #define INTEL386
@@ -589,8 +589,12 @@ Please check your Makefile.
 #include <sys/stat.h>
 #include <unistd.h>
 #else /* !UNIX386 */
-#include <sys\types.h>      /* for unbuffered file I/O */
-#include <sys\stat.h>
+#ifdef H4_HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef H4_HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
 #include <io.h>
 #include <conio.h>          /* for debugging getch() calls */
 #include <malloc.h>
@@ -1249,7 +1253,7 @@ correctly.
 #define HDfreespace HDfree
 
 /**************************************************************************
-*  Allocation functions defined differently 
+*  Allocation functions defined differently
 **************************************************************************/
 #if !defined(MALLOC_CHECK)
 #  define HDmalloc(s)      (malloc((size_t)s))
@@ -1261,7 +1265,7 @@ correctly.
 #define HDfreenclear(p) { if((p)!=NULL) HDfree(p); p=NULL; }
 
 /**************************************************************************
-*  String functions defined differently 
+*  String functions defined differently
 **************************************************************************/
 
 #  define HDstrcat(s1,s2)   (strcat((s1),(s2)))
@@ -1287,7 +1291,7 @@ correctly.
 /**************************************************************************
 *  Misc. functions
 **************************************************************************/
-#define HDstat(path, result)	(stat(path, result))
+#define HDstat(path, result)    (stat(path, result))
 #define HDgetenv(s1)            (getenv(s1))
 #define HDputenv(s1)            (putenv(s1))
 #define HDltoa(v)               (ltoa(v))
