@@ -1,17 +1,17 @@
-C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
-C* Copyright by The HDF Group.                                               *
-C* Copyright by the Board of Trustees of the University of Illinois.         *
-C* All rights reserved.                                                      *
-C*                                                                           *
-C* This file is part of HDF.  The full HDF copyright notice, including       *
-C* terms governing use, modification, and redistribution, is contained in    *
-C* the files COPYING and Copyright.html.  COPYING can be found at the root   *
-C* of the source code distribution tree; Copyright.html can be found at      *
-C* http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
-C* access to either file, you may request a copy from help@hdfgroup.org.     *
-C* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
+C * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
+C  Copyright by The HDF Group.                                               *
+C  Copyright by the Board of Trustees of the University of Illinois.         *
+C  All rights reserved.                                                      *
+C                                                                            *
+C  This file is part of HDF.  The full HDF copyright notice, including       *
+C  terms governing use, modification, and redistribution, is contained in    *
+C  the COPYING file, which can be found at the root of the source code       *
+C  distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+C  If you do not have access to either file, you may request a copy from     *
+C  help@hdfgroup.org.                                                        *
+C * * * * * * * * *  * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 C
-C $Id: mgrf.f 6034 2014-01-19 06:59:14Z epourmal $
+C $Id$
 C
        subroutine mgrf (num_err)
 C
@@ -33,55 +33,11 @@ C
       character*20 myname
       parameter (myname = 'mgrf')
 
-      integer hopen, hclose
-      integer mgstart, mgfinfo, mgend, mgcreat, mgselct 
-      integer mgn2ndx, mggiinf, mgwrimg, mgrdimg, mgendac
-      integer mgid2rf, mgr2idx, mgrltil, mgrimil, mggltid
 c     integer mgwrlut, mgrdlut
-      integer mgglinf, mgwclut, mgrclut
 c      integer mgsattr
-      integer mgatinf, mggattr, mgfndat
+      integer mgrclut, mgwclut
       integer mgscatt, mgsnatt, mggcatt, mggnatt
       integer mgwcimg, mgrcimg
-      integer mggnluts
-      
-      integer MFGR_INTERLACE_PIXEL, MFGR_INTERLACE_LINE,
-     *      MFGR_INTERLACE_COMPONENT
-
-      parameter(MFGR_INTERLACE_PIXEL = 0,
-     *          MFGR_INTERLACE_LINE = 1,
-     *          MFGR_INTERLACE_COMPONENT = 2)
-
-      integer DFACC_READ, DFACC_WRITE, DFACC_CREATE, DFACC_ALL  
-      integer DFACC_RDONLY, DFACC_RDWR, DFACC_CLOBBER
-
-      parameter(DFACC_READ        = 1,
-     *          DFACC_WRITE       = 2,
-     *          DFACC_CREATE      = 4,
-     *          DFACC_ALL         = 7,
-     *          DFACC_RDONLY      = 1,
-     *          DFACC_RDWR = 3,
-     *          DFACC_CLOBBER = 4)
-
-      integer DFNT_INT8,  DFNT_UINT8, 
-     *        DFNT_INT16, DFNT_UINT16,
-     *        DFNT_INT32, DFNT_UINT32, 
-     *        DFNT_INT64, DFNT_UINT64,
-     *        DFNT_INT128,DFNT_UINT128,
-     *        DFNT_CHAR8, DFNT_UCHAR8
- 
-      parameter(DFNT_INT8       = 20,
-     *          DFNT_UINT8      = 21,
-     *          DFNT_INT16      = 22,
-     *          DFNT_UINT16     = 23,
-     *          DFNT_INT32      = 24,
-     *          DFNT_UINT32     = 25,
-     *          DFNT_INT64      = 26,
-     *          DFNT_UINT64     = 27,
-     *          DFNT_INT128     = 28,
-     *          DFNT_UINT128    = 29,
-     *          DFNT_CHAR8      = 4,
-     *          DFNT_UCHAR8     = 3)
       integer il
       character*80 TESTFILE
       character*80 IMAGE1, IMAGE2, IMAGEC, IMAGEC_2
