@@ -47,12 +47,12 @@ typedef unsigned int UINT;
 
 #include <stdio.h>
 
-#ifdef UNIX
+#include "hdf.h"
+
+#ifdef H4_HAVE_SYS_FILE_H
 #include <sys/file.h>
 #endif
 
-#include "hdf.h"
-
 #define USAGE   fprintf (stderr, "usage: hdf24hdf8 hdf24_file hdf8_file\n")
 
 int         main
