@@ -29,8 +29,14 @@
 #include "hdf.h"
 #include <stdio.h>
 #include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
+
+#ifdef H4_HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
+
+#ifdef H4_HAVE_SYS_STAT_H
+# include <sys/stat.h>
+#endif
 
 #define DefaultDatafile "DataFile"
 
