@@ -5,13 +5,13 @@
  *                                                                           *
  * This file is part of HDF.  The full HDF copyright notice, including       *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at      *
- * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: he_file.c 6357 2016-05-13 05:00:06Z bmribler $ */
+/* $Id$ */
 
 /* --- he-file.c  --- file and annotation manipulation routines */
 #include "he.h"
@@ -20,7 +20,7 @@
 #if defined SUN | defined HP9000 | defined IRIX | defined UNIX386
 #include <sys/wait.h>
 #endif /* SUN | HP9000 */
-#if defined _POSIX_SOURCE | defined IRIX
+#ifdef H4_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
