@@ -5,13 +5,13 @@
  *                                                                           *
  * This file is part of HDF.  The full HDF copyright notice, including       *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at      *
- * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: he_main.c 6357 2016-05-13 05:00:06Z bmribler $ */
+/* $Id$ */
 
 /******************************************************************************
  * he - HDF editor
@@ -66,7 +66,7 @@
 #include "he.h"
 
 #include <stdio.h>
-#ifndef _WIN32
+#ifdef H4_HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
@@ -1130,7 +1130,7 @@ quit(int status)
               return HE_FAIL;
       }
     exit(status);
-    return(status);	/* never excuted.  Just to shut up some comilers */
+    return(status);    /* never excuted.  Just to shut up some comilers */
 }
 
 int
