@@ -8,13 +8,13 @@
  *                                                                           *
  * This file is part of HDF.  The full HDF copyright notice, including       *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at      *
- * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* $Id: local_nc.h 6450 2016-06-16 06:38:24Z bmribler $ */
+/* $Id$ */
 #ifndef _LOCAL_NC_
 #define _LOCAL_NC_
 
@@ -31,21 +31,49 @@
 #endif
 
 /* Do we have system XDR files */
-#ifndef  NO_SYS_XDR_INC
+#ifndef  H4_NO_SYS_XDR_INC
+
+#ifdef __CYGWIN__
+#ifndef __u_char_defined
+typedef    unsigned char    u_char;
+#define __u_char_defined
+#endif
+#ifndef __u_short_defined
+typedef    unsigned short    u_short;
+#define __u_short_defined
+#endif
+#ifndef __u_int_defined
+typedef    unsigned int    u_int;
+#define __u_int_defined
+#endif
+#ifndef __u_long_defined
+typedef    unsigned long    u_long;
+#define __u_long_defined
+#endif
+#endif /* __CYGWIN__ */
+
 #include    <rpc/types.h>
 #include    <rpc/xdr.h>
-#else    /* NO_SYS_XDR_INC */
-#include      <types.h>  /* <types.h */
-#include      <xdr.h>    /* <xdr.h> */
-#endif /* NO_SYSTEM_XDR_INCLUDES */
+#else    /* H4_NO_SYS_XDR_INC */
+#include      "types.h"  /* <types.h */
+#include      "xdr.h"    /* <xdr.h> */
+#endif /* H4_NO_SYS_XDR_INC */
 
-#include "H4api_adpt.h"
 #ifdef H4_HAVE_NETCDF
 #include    "netcdf.h" /* needed for defs of nc_type, ncvoid, ... */
 #else
 #include "hdf4_netcdf.h"
 #endif
 
+/* Constants for sizes of NC types */
+#define NC_BYTE_SIZE        1
+#define NC_CHAR_SIZE        1
+#define NC_SHORT_SIZE       2
+#define NC_LONG_SIZE        4
+#define NC_FLOAT_SIZE       4
+#define NC_DOUBLE_SIZE      8
+#define NC_UNSPECIFIED_SIZE 0
+
 /* ptr argument type in internal functions */
 #define Void    char
 
