@@ -5,10 +5,10 @@
  *                                                                           *
  * This file is part of HDF.  The full HDF copyright notice, including       *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at      *
- * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /* $Id: hdftest.c 5218 2009-08-29 04:21:49Z bmribler $ */
@@ -92,7 +92,7 @@ main(int argc, char *argv[])
     int32   scale[10];
     char    l[80], u[80], fmt[80], c[80];
     int32   count;
-    int32   fillval, readval;
+    int32   fillval=0, readval=0;
     int32   idata[100];
     int32   rdata[100];
     int16   sdata[100], outdata[100];
