@@ -5,10 +5,10 @@
  *                                                                           *
  * This file is part of HDF.  The full HDF copyright notice, including       *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at      *
- * http://hdfgroup.org/products/hdf4/doc/Copyright.html.  If you do not have *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://support.hdfgroup.org/ftp/HDF/releases/.  *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /****************************************************************************
@@ -107,7 +107,7 @@ test_SDSnames()
 
     /* Allocate buffer to get its name */
     ds_name = (char *)HDmalloc(name_len+1);
-    CHECK(ds_name, NULL, "HDmalloc");
+    CHECK_ALLOC(ds_name, "ds_name", "test_SDSnames");
 
     /* Get information of the first dataset, and verify its name */
     status = SDgetinfo(dset1, ds_name, &rank, dimsizes, &dtype, &nattrs);
@@ -133,7 +133,7 @@ test_SDSnames()
 
     /* Allocate buffer to get its name */
     ds_name = (char *)HDmalloc(name_len+1);
-    CHECK(ds_name, NULL, "HDmalloc");
+    CHECK_ALLOC(ds_name, "ds_name", "test_SDSnames");
 
     /* Get information of the second dataset, and verify its name */
     status = SDgetinfo(dset2, ds_name, &rank, dimsizes, &dtype, &nattrs);
